@@ -191,8 +191,23 @@ mediaShow.loadSlide = function (slideshow, slideNumber)
         }
         else
         {
-          descriptionDiv = $('<div class="mediaShowDescription">'+data.description+'</div>');
+	  var separator = " ";
+	  if (data.description != "")
+	  {
+		separator = " - ";
+	  }
+	  
+	  var breadcrumb = (slideNumber + 1) + " of " + slideshow.size + separator;
+	  if (onSlodeshowSkipPrev == null && slideshow.size <= 1)
+	  {
+		descriptionDiv = $('<div class="mediaShowDescription">'+ data.description +'</div>');
+	  }
+          else
+	  {
+		descriptionDiv = $('<div class="mediaShowDescription">'+ breadcrumb + data.description + '</div>');
+	  }
         }
+	
         var infoDiv = $('<div class="mediaShowInfo"></div>');
         
         infoDiv.append(descriptionDiv);
